#!/apps/local/bin/perl

#---------------------------------------------------------------------
# Program Name: rcliper_run.pl
#
# Language: Perl 5.x
#
# Purpose: 
#
# Information:
#    Joint Hurricane Testbed/USWRP project
#    National Hurricane Center / Tropical Prediction Center
#    Department of Commerce - NOAA / NWS
#
# Called by: command line
#
# Calls:  
#
#
# Category: Joint Hurricane Testbed Project - RCliper (2002)
#
# Written by: Alison Krautkramer 09/2002
#---------------------------------------------------------------------

#---------------------------------------------------------------------
#Directories
#---------------------------------------------------------------------

#Specify name of directory containing required scripts/executables
#also the working dir where files get copied to and run on.
$scriptDir = "/home/akrautkr/programs/rcliper/TRMM_rcliper";

#Specify name of directory containing storm independent data files
#		aland.dat
$geodataDir ="/home/akrautkr/programs/rcliper/TRMM_rcliper/data";

#Specify the name of the directory to get the computes files
#$computesDir="/home/akrautkr/programs/computes";
$computesDir = "/home/akrautkr/.working";
$workingDir =  "/home/akrautkr/.working";
#$processDir = "/home/akrautkr/programs/perlFunctions";

#Specify name of directory to put rcliper text output
#$outputDir="/data/jhtPrograms/TRMM_rcliper";
$outputDir = "/home/akrautkr/.working";

#-------------------------------------------------------------
#Open a log file to get all of the errors/output from
#the Rcliper program
#--------------------------------------------------------------

# Remove the old log file and create a new one
unlink ("$scriptDir/rcliper_run.log");
system("touch $scriptDir/rcliper_run.log");

if (-e "$scriptDir/rcliper_run.log") {	
	#Open file for writing
	open(LOG, ">$scriptDir/rcliper_run.log");
}
else {
	printf ("Error: Could not create the log file\n");
	exit 1;
}

#------------------------------------------------------------
#User Input
#-------------------------------------------------------------
#Find the name of the file that the user would like to plot
if (@ARGV == 0) {
	printf ("Enter computes file name\n");
    exit 1;
}
elsif (@ARGV == 1) {
	$returnValue = isFile("$workingDir/$ARGV[0]");
	if ($returnValue != 1) {
		printf ("Error computes file $returnValue\n");
		exit 1;
	}
	$userInput = $ARGV[0]; 
}


#-----------------------------------------------------------
#Get the user input
#-------------------------------------------------------------
#Get the input file from the user
#Check the existance of the $computesDir
#if (-d $computesDir) {
#
#	#Open the $computesDir and print out all of the file
#	#names found for the user to choose from.  Then close
#	#the $computesDir.
#    printf ("Computes files: \n");
#    opendir (COMPUTES, $computesDir) || die "Error: Can't open $computesDir";
#
#    #Read each file in the $computesDir and print out the 
#    #names in a list for the user to select
#    while (defined($file = readdir(COMPUTES))) {
#
#        #Choose the next entry in the directory if:
#        #the entry is either the current or present directory
#         next if $file =~ /^\.\.?$/;
#         printf ("   $file \n");
#    }
#    closedir COMPUTES;
#
#    #Read the user input
#    printf ("Enter the name of the computes file: ");
#    $userInput = <STDIN>;
#    
#    #Remove the end of line character
#    chomp($userInput);
#    
#    #Remove any excess spaces in the users input
#    $userInput =~ s/\s+//;
#    
#    #Check for the existance of the users input
#    if (!(-e "$computesDir/$userInput")) {
#    	printf (LOG "Error: The file chosen does not exist.\n");
#		close LOG;
#	    exit 1;
#    }
#}
#else {
#    printf (LOG "Error: The directory $computesDir does not exist.\n");
#	close LOG;
#    exit 1;
#}

#-------------------------------------------------------------------------
#Move the files to the needed directories and run rcliper
#-------------------------------------------------------------------------
#Copy needed data files to current directory
if (-d $geodataDir) {
  system ("cp $geodataDir/aland.dat $workingDir/aland.dat");
}
else {
  printf ( LOG "Error: Directory does not exist $geodataDir\n");
  close LOG;
  exit 1;
}

#find the current system date/time
#system("date >$date");
	
	print LOG "Begin rcliper_run\n";
	#print LOG "$date \n";  
	print LOG  "  \n";

#cp the user selected computes file to the 
#script dir
unlink("$workingDir/comab.dat");
system("cp $workingDir/$userInput $workingDir/comab.dat");
	
	print LOG "comab.dat file for model run: \n"; 
	#cat comab.dat                         
	print LOG "  \n"; 
	
#Copy the rcliper.x executable to the working directory
system("cp $scriptDir/rcliper.x $workingDir");
	
# Check to make sure comab.dat file is not empty
if (-s "$workingDir/comab.dat") {
		
	#Calculate rainfall
    #system ("$scriptDir/rcliper.x");
	system ("$workingDir/rcliper.x");	
		
		print LOG "   \n";
		print LOG " Log file from RCLIPER run \n ";
		#cat rcliper.log 

	# Move resulting text file
	system ("mv $workingDir/*rcliper.txt $outputDir");
	
	#find the current system date/time
	#system("date >$date");
		
		print LOG "rcliper_run completed\n";
		#print LOG "$date\n";                     
}
else {
	    print LOG "$workingDir/comab.dat file is empty, halt rcliper processing.\n";
   		close LOG;
		exit 1;
}                   

#-------------------------------------------------------------------------
# Clean up after model run
#-------------------------------------------------------------------------
close (LOG);
unlink (" $workingDir/comab.dat");
unlink (" $workingDir/aland.dat");


#--------------------------------------------------------
# Subroutine: isFile
#
# Purpose:
#
# Inputs: $_[0] - absolute path to a file
#		  $_[1] - filename
#
# Outputs: 1 - success
#
# Errors:  -1 file does not exist
#		   -5 file has with zero size 
#--------------------------------------------------------
sub isFile {

	#define local variables
	my($path, $file) = @_;
	
	#check that $path is not a directory
	if (! (-d "$path/$file")) {
		
		#check that $path is a file
		if (-e "$path/$file") {
			
			#check that the file size neq 0
			if (-z "$path/$file") {
				#return error: file has zero size
				return -5;
			}
			else {
				return 1;
			}
		}
		else {
			#return error: file does not exist
			return -1;
		}
	}
	else {
		#return error: file does not exist
		return -1;
	}
}
