      subroutine rrcal(time,vmax,rad,rrate)
c     This routine calculates the rain rate (rrate, inches per hour)
c     as a function of the time inland (time, hr), the maximum 
c     winds (vmax, kt), and the radius from the storm center (rad, km).
c
c     Set igauge=1 to use rate from rain gauge analysis
c      or igauge=0 to use rate from TRMM climatology
c
      igauge= 0 
c
      if (igauge .eq. 0) go to 1000
c
c     Rainfall rate from gauge climatology (function of t,r)
      a0  = 6.4/24.0
      b0  = 1.0/24.0
      al  = 0.029
      srad = 20.0
      erad = 160.0
c
      tt = time
      if (tt .lt. 0.0) tt = 0.0 
      tf = exp(-al*tt)
c
      if (rad .le. srad) then
	 rrate = (a0*tf+b0)
      else
         rrate = (a0*tf+b0)*exp(-(rad-srad)/erad)
      endif
c
      return
c
 1000 continue
c     Rainfall rate from TRMM climatology (function of vmax,r)
c
      vmaxt = vmax
      if (vmaxt .lt.  35.0) vmaxt = 35.0
      if (vmaxt .gt. 136.0) vmaxt = 136.0
c
      xn = 1.0 + (vmaxt - 35.0)/33.0
c
      t0 =  (3.96*xn - 1.10)/24.0
      tm =  (4.80*xn - 1.60)/24.0
      rm =  -13.0*xn + 64.5
      re = -16.0*xn + 150.0
c
      if (rad .le. rm) then
	 rrate = t0 + (tm-t0)*(rad/rm)
      else
	 rrate = tm*exp(-(rad-rm)/re)
      endif
c
      return
      end
