       PROGRAM rcliper_newi
c     This program makes a forecast of storm total rainfall
c     using a climatological tropical cyclone rain rate 
c     that is moved along the forecast storm track. 
c
c     In this version, the track and intensity input is read from a .job file 
c     that uses 6 h best track positions
c
c     Output is 30 X 30 deg in 121 X 121 1/4 deg bins
c
      CHARACTER *2 basin
      CHARACTER *10 sname
      CHARACTER *30 fndat, fnlog	!fdm
      CHARACTER *32 infile      ! pal
      CHARACTER *120 jinfile     ! pal
      INTEGER predim, ludat, lulog	!fdm

c     Storm track/intensity arrays
c      PARAMETER (predim = 60)   ! pal ! fdm
      PARAMETER (predim = 200)   ! fdm
      DIMENSION slat(predim), slon(predim), svmx(predim), stime(predim) ! pal

c     Rainfall grid arrays
      PARAMETER (nx = 121, ny = 121)
      DIMENSION glon(nx), glat(ny)
      DIMENSION raintot(nx, ny)

      DATA      ludat, lulog /80, 81/
C        1         2         3         4         5         6         7 ^
C2345678901234567890123456789012345678901234567890123456789012345678901234567890
c     Specify rainfall grid spacing (deg lat/lon)
      drg = 0.25

c     Open the input file (fdm)
      OPEN(1, FILE = '/dev/tty')  ! pal
      write(1,'("Enter input filename(<32 char): ")')
      read (1,*) infile

c     Get the storm track and intensity parameters from the input file.
      OPEN(85, ERR = 999, FILE = infile, IOSTAT = ios, STATUS = 'old')  ! pal
15    READ(85, *, ERR = 991, IOSTAT = ier) luout    ! pal
      READ(85, '(A2, /, A10)', ERR = 991, IOSTAT = ier) basin, sname  ! pal
      READ(85, *, ERR = 991, IOSTAT = ier) isnum, iyra, imona, idaya,
     +  itimea, mt   ! pal

c     Specify the input parameters
c     Time values
      DO kount = 1, mt
        stime(kount) = 6.0 * FLOAT(kount - 1)  ! fdm
c        stime(kount) = FLOAT(kount - 1)   ! fdm change for 1 h interval fixes
        READ(85, *, ERR = 991, IOSTAT = ier)
     +    slat(kount), slon(kount), svmx(kount)
        slon(kount)=-1*slon(kount)
      ENDDO
c
c     Limit intensity to 20 kt or greater
      do k=1,mt
	     if (svmx(k) .gt. 0.0 .and. svmx(k) .lt. 20.0) svmx(k) = 20.0
      enddo
c
c     Create the log and output file names	!fdm
      if (iyra .lt. 2000) then
	 iyr2 = iyra - 1900
      else
	 iyr2 = iyra - 2000
      endif
c
c    Open log output file		!fdm
      write(fnlog,501) iyr2,imona,idaya,itimea,basin,isnum		!fdm
501   format(4(i2.2),a2,i2.2,'_log.txt')
c
      OPEN(UNIT = lulog, FILE = fnlog, FORM = 'formatted',
     +  STATUS = 'unknown')
c
      write(lulog,200) basin,isnum,iyra,imona,idaya,itimea,sname
200   format(' RCLIPER forecast for ',a2,i2.2,i4.4,1x,3(i2.2),1x,a10)
c
      write(lulog,205) 
205   format(/,' Track/Intensity')
      do k=1,mt
	    write(lulog,210) stime(k),slat(k),slon(k),svmx(k)
210         format(1x,f4.0,1x,f5.1,1x,f6.1,1x,f4.0)
      enddo
c
      if (ier .ne. 0) then
         write(lulog,900) ierr
900      format(/,' Error in RCLIPER, ierr=',i2)
	 stop
      endif
c
c     Calculate storm total rainfall
      call str(mt,slat,slon,svmx,stime,nx,ny,drg,lulog,
     +            glat,glon,raintot)
c
      write(fndat,500) iyr2,imona,idaya,itimea,basin,isnum
500   format(4(i2.2),a2,i2.2,'_rcliper.txt')
c
      write(lulog,215) fndat, fnlog
215   format(/,' Output file name: ',a30,/,' Log file name: ',a30)
c
c     Open and write the data file
      open(file=fndat,unit=ludat,form='formatted',status='unknown')
c
c     Write header records
      write(ludat,300) basin,isnum,iyra,imona,idaya,itimea,sname
300   format(a2,i2.2,i4.4,1x,3(i2.2),1x,a10)
c
      write(ludat,305) nx,drg,glon(1),glon(nx),
     +                 ny,drg,glat(1),glat(ny)
305   format(1x,i3,1x,3(f8.3,1x),i3,1x,3(f8.3,1x))
c
c
      DO k = 1, mt  ! pal
	  write(ludat,307) -slon(k),slat(k),stime(k)
307      format(1x,f7.2,1x,f6.2,1x,f5.1)
      enddo
c
      DO j = 1, ny
        DO i = 1, nx
          WRITE(ludat, 310) glon(i), glat(j), raintot(i, j)
310       FORMAT(3(1X, F8.3))
        ENDDO
      ENDDO
      GOTO 99999
C-------------------------------------------------------------------------------
C     ERROR STATEMENTS  ! pal
991   WRITE(luout, '("error on reading input .JOB file:", I4)') ier
      STOP 991
993   WRITE(luout, '(1X, A49, " open ER=", I4, " not in directory")')
     +  jinfile, ios
      STOP 993
999   WRITE(luout,'(1X,A30," open ER=",I4," trying cases/tracks")')
     +  infile, ios
      jinfile='~/Documents/TC_Rain/R-CLIPER/cases/tracks/' // infile
      OPEN(5, ERR = 993, FILE = jinfile, IOSTAT = ios, STATUS = 'OLD')
      GOTO 15
c
99999 STOP
      END
C-------------------------------------------------------------------------------
      subroutine tdiff(iy2,im2,id2,it2,iy1,im1,id1,it1,idelt)
c     This routine calculates the number of hours (delt) between
c     two date/times.
c
      dimension nday(12)
c
      data nday /0,31,59,90,120,151,181,212,243,273,304,334/
c
c     Calculate reference year
      iry = iy1-2
      if (iy2 .lt. iry) iry=iy2-2
c
c     Calculate the number of hours from 00 Jan. 1 of the reference year
      ity1 = 0
      do 10 i=iry,iy1-1
         if (mod(i,4) .eq. 0) then
            ity1 = ity1 + 24*366
         else
            ity1 = ity1 + 24*365
         endif
   10 continue
c
      ity2 = 0
      do 15 i=iry,iy2-1
         if (mod(i,4) .eq. 0) then
            ity2 = ity2 + 24*366
         else
            ity2 = ity2 + 24*365
         endif
   15 continue
c
      ity1 = ity1 + 24*nday(im1)
      if ((mod(iy1,4) .eq. 0) .and. im1 .gt. 2) ity1=ity1+24
c
      ity2 = ity2 + 24*nday(im2)
      if ((mod(iy2,4) .eq. 0) .and. im2 .gt. 2) ity2=ity2+24
c
      ity1 = ity1 + 24*id1 + it1
      ity2 = ity2 + 24*id2 + it2
c
      idelt = ity2 - ity1
c
      return
      end
C------------------------------------------------------------------------------
      subroutine xint(x,f,n,iflag,lflag,xi,fi,ierr)
c     This routine applies a quadratic interpolation procedure
c     to f(x) between x(1) and x(n). f(x) is assumed to be
c     represented by quadratic polynomials between the points
c     x(i). The polynomials are chosen so that they equal f(i)
c     at the points x(i), the first derviatives on either
c     side of the interior x(i) match at x(i), and the second
c     derivative of the approximated function integrated
c     over the domain is minimized.
c
c     This version is for interpolating longitude
c
c     Input:  x(1),x(2) ... x(n)      The x values (must be sequential)
c             f(1),f(2) ... f(n)      The function values
c             n                       The number of x,f pairs
c             iflag                   Flag for initialization
c                                      =1 for coefficient calculation
c                                      =0 to use previous coefficients
c             lflag                   Flag for linear interpolation
c                                      =0 to perform linear interpolation 
c                                      =1 to perform quadratic interpolation
c             xi                      The x value at which to interpolate f
c
c     Output: fi                      The interpolated function value
c             ierr                    Error flag
c                                      =0  Normal return
c                                      =1  Parameter nmax is too small
c                                      =2  The x values are not sequential
c                                      =3  Coefficient iteration did not
c                                          converge
c                                      =4  Mix-up finding coefficients
c                                      =5  if xi .gt. x(n) or .lt. x(1),
c                                          xi is set to nearest endpoint
c                                          before the interpolation
c
c                                     Note: fi is set to -99.9 if
c                                           ierr=1,2,3 or 4
c
      parameter (nmax=5000)
c
      dimension x(n),f(n)
c
c     Save variables
      dimension ax(nmax),bx(nmax),cx(nmax)
c
c     Temporary local variables
      dimension df(nmax),dx(nmax),gm(nmax),ct(nmax)
c
      common /xsave/ ax,bx,cx
c
c     Specify unit number for debug write statements
c     and debug flag
      idbug  = 0
      lutest = 6
c
c     Initialize error flay
      ierr = 0
c
c     Specify minimum reduction in cost function for convergence
      thresh = 1.0e-10
c
c     Check to make sure nmax is large enough, and n is .gt. 1 
      if (n .gt. nmax .or. n .lt. 2) then
         ierr=1
         fi = -99.9
         return
      endif
c
      if (iflag .eq. 1) then
c        Perform the initialization for later interpolation
c
c        Check to make sure x is sequential
         do 10 i=1,n-1
            if (x(i) .ge. x(i+1)) then
               ierr=2
               fi = -99.9
               return
            endif
   10    continue
c
c        Check for special case where n=2. Only linear interpolation
c        is possible.
         if (n .eq. 2) then
            cx(1) = 0.0
            bx(1) = (f(2)-f(1))/(x(2)-x(1))
            ax(1) = f(1) - bx(1)*x(1)
            go to 1500
         endif
c
c        Calculate x and f differences
         do 15 i=1,n-1
            df(i) = f(i+1)-f(i)
            dx(i) = x(i+1)-x(i)
   15    continue
c
c        Calculate domain size
         d = x(n) - x(1)
c
c        Check for linearity of input points
         eps = 1.0e-10
         bb = (f(2)-f(1))/(x(2)-x(1))
         aa = f(1) - bb*x(1)
         dev = 0.0
         do 12 i=3,n
            dev = dev + abs(aa + bb*x(i) - f(i))
   12    continue
c
         if (dev .lt. eps .or. lflag .eq. 0) then
            do 13 i=1,n-1
               cx(i) = 0.0
   13       continue
            go to 1000
         endif
c
c        Iterate to find the c-coefficients
         cx(1) = 0.0
         nit  = 100
         slt  = 0.01
         cfsave = 1.0e+10
c
         do 20 k=1,nit
c           Calculate c values
            do 25 i=2,n-1
               cx(i) = -cx(i-1)*dx(i-1)/dx(i) 
     +                -df(i-1)/(dx(i)*dx(i-1))
     +                +df(i  )/(dx(i)*dx(i  ))
   25       continue
c
c           Calculate current value of cost function
            cf0 = 0.0
            do 26 i=1,n-1
               cf0 = cf0 + cx(i)*cx(i)*dx(i)
   26       continue
            cf0 = 0.5*cf0/d
c
            if (idbug .ne. 0) then
               write(lutest,101) cf0
  101          format(/,' cf0=',e13.6)
            endif
c
c           Check for convergence
            rel = abs(cf0 - cfsave)/abs(cfsave)
            if (rel .lt. thresh) go to 1000
            cfsave = cf0
c
c           Calculate values of Lagrange multipliers
            gm(n-1) = cx(n-1)*dx(n-1)/d
c
            if (n .gt. 3) then
               do 30 i=n-2,2,-1
                  gm(i) = cx(i)*dx(i)/d - gm(i+1)*dx(i)/dx(i+1)
   30          continue
            endif
c
c           Calculate gradient of cost function with respect to c1
            dsdc1 =  dx(1)*(cx(1)/d - gm(2)/dx(2))
c
c           Adjust cx(1) using trial step
            ct(1) = cx(1) - slt*dsdc1
c
c           Calculate remaining c values at trial step
            do 33 i=2,n-1
               ct(i) = -ct(i-1)*dx(i-1)/dx(i) 
     +                 -df(i-1)/(dx(i)*dx(i-1))
     +                 +df(i  )/(dx(i)*dx(i  ))
   33       continue
c
c           Calculate cost function at trial step
            cft = 0.0
            do 31 i=1,n-1
               cft = cft + ct(i)*ct(i)*dx(i)
   31       continue
            cft = 0.5*cft/d
c
c            write(6,*) 'dsdc1,cft,cf0',dsdc1,cft,cf0
c           Calculate optimal step length and re-adjust cx(1)
            den = 2.0*((cft-cf0) + slt*dsdc1*dsdc1)
            if (den .ne. 0.0) then
               slo = dsdc1*dsdc1*slt*slt/den
            else
               slo =0.0
            endif
c
c           Adjust slo if desired
            slo = 1.0*slo
c
            cx(1) = cx(1) - slo*dsdc1
c
            if (idbug .ne. 0) then
               write(lutest,100) k,cft,slt,slo
  100          format(' Iteration=',i4,'  cf1=',e11.4,' slt=',e11.4,
     +                                                ' slo=',e11.4)
c     
               do 99 j=1,n-1
                  write(lutest,102) j,cx(j)
  102             format('    i=',i2,' c=',f8.4)
   99          continue
            endif
c
c           Calculate trial step for next time step
            slt = 0.5*slo
   20    continue
c
c        Iteration did not converge
         ierr=3
         fi=-99.9
         return
c
c        Iteration converged
 1000    continue
c
         if (idbug .ne. 0) then
            write(lutest,104)
  104       format(/,' Iteration converged')
         endif
c
c        Calculate b and a coefficients
         do 40 i=1,n-1
            bx(i) = df(i)/dx(i) - cx(i)*(x(i+1) + x(i))
            ax(i) = f(i) - bx(i)*x(i) - cx(i)*x(i)*x(i)
   40    continue        
      endif
c
 1500 continue
c     Interpolate the function
c
c     Check for xi out of bounds
      if (xi .lt. x(1)) then
         xi = x(1)
         ierr = 5
      endif
c
      if (xi .gt. x(n)) then
         xi = x(n)
         ierr = 5
      endif
c
c     Find the interval for the interpolation
      ii = 1
      do 50 i=2,n
         if (xi .le. x(i)) then
            ii = i-1
            go to 2000
         endif
   50 continue
c
      fi = -99.9
      ierr=4
      return
c
 2000 continue
      fi = ax(ii) + bx(ii)*xi + cx(ii)*xi*xi
c
      return
      end
C-------------------------------------------------------------------------------
      subroutine ctorh(x,y,r,theta)
c     This routine converts from Cartesion coordinates
c     to radial coordinates, where theta is in
c     degrees measured clockwise from
c     the +y-axis (standard meteorological heading).
c
      r = sqrt(x*x + y*y)
c
      if (r .le. 0.0) then
         theta = 0.0
         return
      endif
c
      rtd = 57.296
      theta = rtd*acos(x/r)
      if (y .lt. 0.0) theta = 360.0 - theta
c
c     Convert theta to heading
      theta = 90.0 - theta
      if (theta .lt. 0.0) theta = theta + 360.0
c
      return
      end
C------------------------------------------------------------------------------
      subroutine str(mt,slat,slon,svmx,stime,nx,ny,drg,lulog,
     +               glat,glon,raintot)
c     This routine calculates the storm-total rainfall (inches)
c     using a climatological tropical cyclone rainfall rate as
c     a function of radius from the storm center and time
c     since landfall. 
c
c     Track variables
      dimension slat(mt),slon(mt),svmx(mt),stime(mt)
c
c     Arrays for time interpolation routines
      parameter (nmax=5000)
      dimension ax(nmax),bx(nmax),cx(nmax)
c
c     Interpolated track variables
      PARAMETER (mti = 5000)  ! pal
      dimension slati(mti),sloni(mti),svmxi(mti),stimei(mti)
      dimension sspd(mti),shead(mti),stildi(mti)
      dimension dtl(mti)
c
c     Rainfall grid variables
      dimension glon(nx),glat(ny)
      dimension raintot(nx,ny)
c
      common /xsave/ ax,bx,cx
c
c     Calculate the half width of the longitudal domain
      dlonl = 0.5*(float(nx-1)*drg)
c
c     Specify the degress latitude below the landfall point 
c     for starting the rainfall grid.
      dlatb = 0.5*(float(ny-1)*drg)
c
c     Specify time interval (hr) number of time intervals 
c     for interpolated track/intensity
      dt  = 0.1
      nti = mti ! 800 fdm
c
      do 10 i=1,nti
         stimei(i) = dt*float(i-1)
   10 continue
c
c     Find maximum time for which there is a track forecast
      nt = mt
      tfmax = stime(nt)
c      do 15 k=1,mt
c         if (slat(k) .le. 0.0 .or. slon(k) .le. 0.0) then
c            tfmax = stime(k-1)
c            nt = k-1
c            go to 1015
c         endif
c   15 continue
 1015 continue
c
      if (nt .lt. 2) then
         write(lulog,900) 
  900    format(/,' There must be at least two track points')
         stop
      endif
c
c     Make sure intensity forecast exists for all track points
      if (svmx(1) .le. 14.0) then
         write(lulog,901)
  901    format(/,' There must be at least one intensity point')
      endif
c
c     Check intensity points and extrapolate if necessary
      do 19 i=2,nt
         if (svmx(i) .lt. 20.0) svmx(i)=svmx(i-1)
   19 continue
c
      ntemp = nti
      do 20 i=1,nti
         if (stimei(i) .gt. tfmax) then
            ntemp = i-1
            go to 1020
         endif
   20 continue
 1020 nti = ntemp
c
      write(lulog,200) tfmax,nti,dt
  200 format(/,' Track forecast out to ',f4.0,' hrs',//,
     +         ' Divide track into ',i3,' points',f4.1,' hrs apart')
c
c     Interpolate track forecast to small time steps (dt)
      lflag=1
c
      do 25 i=1,nti
         if (i .eq. 1) then
            iflag=1
         else
            iflag=0
         endif
         ttemp = stimei(i)
         call xint(stime,slon,nt,iflag,lflag,ttemp,xtemp,ierrx)
c
         sloni(i) = -xtemp
   25 continue
c
      do 26 i=1,nti
         if (i .eq. 1) then
            iflag=1
         else
            iflag=0
         endif
         ttemp = stimei(i)
         call xint(stime,slat,nt,iflag,lflag,ttemp,xtemp,ierrx)
c
         slati(i) =  xtemp
   26 continue
c
c     Linearly interpolate intensity to small time steps
c     and calculate storm speed/heading 
      lflag=0
      do 27 i=1,nti
         if (i .eq. 1) then
            iflag=1
         else
            iflag=0
         endif
         ttemp = stimei(i)
         call xint(stime,svmx,nt,iflag,lflag,ttemp,xtemp,ierrx)
         svmxi(i) = xtemp
c
         if (i .eq. 1) then
	    x1 = sloni(1) 
	    y1 = slati(1) 
            t1 = stimei(1) 
	    x2 = sloni(2) 
	    y2 = slati(2) 
            t2 = stimei(2) 
         elseif (i .eq. nti) then
	    x1 = sloni(nti-1) 
	    y1 = slati(nti-1) 
            t1 = stimei(nti-1) 
	    x2 = sloni(nti) 
	    y2 = slati(nti) 
            t2 = stimei(nti) 
         else
	    x1 = sloni(i-1) 
	    y1 = slati(i-1) 
            t1 = stimei(i-1) 
	    x2 = sloni(i+1) 
	    y2 = slati(i+1) 
            t2 = stimei(i+1) 
         endif
c
         call spdhead(x1,y1,t1,x2,y2,t2,sspd(i),shead(i))
   27 continue
c
c     Calculate the distance to land at the interpolated positions
      do 30 i=1,nti
         call aland(sloni(i),slati(i),dtl(i))
   30 continue
c
c     Calculate the time since landfall at any point along 
c     the interpolated track
      if (dtl(1) .ge. 0.0) then
         stildi(1) = 0.0
      else
c        If the first position is over land, estimate
c        the time since landfall based upon the current
c        speed and the distance to land.
         call distk(sloni(1),slati(1),sloni(2),slati(2),
     +              dx,dy,dxy)
         speed = dxy/(stimei(2)-stimei(1))
         time1 = -dtl(1)/speed
         stildi(1) = dt*ifix(time1/dt)
      endif
c
      do 32 i=2,nti
         if (dtl(i) .lt. 0.0) then
            stildi(i) = stildi(i-1) + dt
         else 
            stildi(i) = 0.0
         endif
   32 continue
c
c     Find the time when the storm first moves inland
      ntin = -99
      do 35 i=1,nti
         if (dtl(i) .le. 0.0) then
            ntin = i
            go to 1035
         endif
   35 continue
 1035 continue
c
      iprint=0
      if (iprint .eq. 1) then
         do 37 i=1,nti
            write(lulog,210) stimei(i),stildi(i),
     +      sloni(i),slati(i),svmxi(i),sspd(i),shead(i),dtl(i)
  210       format(' t,tld,lon,lat,vmx,c,head,dtl: ',6(f7.2,1x),
     +             2(1x,f7.0))
   37    continue
      endif
c
      if (ntin .gt. 0) then
         write(lulog,220) ntin,stimei(ntin),sloni(ntin),slati(ntin),
     +                    dtl(ntin)
  220    format(/,' Storm inland at',i4,', t=',f5.1,' lon/lat: ',
     +             f7.1,1x,f6.1,'  dtl=',f6.1)
         tland = stimei(nti)
      else
         ntin = nti/2
         write(lulog,230) ntin,stimei(ntin),sloni(ntin),slati(ntin),
     +                    dtl(ntin)
  230    format(/,' Storm not inland at',i4,', center grid at',/,
     +            '  t=',f5.1,' lon/lat: ',
     +               f7.1,1x,f6.1,'  dtl=',f6.1)
         tland = 999.9
      endif
c
c     Choose reference point for calculation of rainfall grid
      glon0 =  float(ifix(sloni(ntin) - 0.49))
      glat0 =  float(ifix(slati(ntin) + 0.49))
c
      write(lulog,240) glon0,glat0
  240 format(/,' Rainfall grid reference lon/lat: ',f7.1,1x,f6.1)
c
c     Calculate rainfall grid variables
      do 40 i=1,nx
         glon(i) = (glon0-dlonl) + drg*float(i-1)
   40 continue
c 
      do 42 j=1,ny
         glat(j) = (glat0-dlatb) + drg*float(j-1)
   42 continue
c
c     Calculate storm total rainfall
      do 44 j=1,ny
      do 44 i=1,nx
         raintot(i,j) = 0.0
   44 continue
c
      do 45 k=1,nti
         time = stildi(k)
         vmax = svmxi(k)
c
         do 46 j=1,ny
         do 46 i=1,nx
            call distk(sloni(k),slati(k),glon(i),glat(j),
     +                 dx,dy,rad)
            call rrcal(time,vmax,rad,rrate)
            raintot(i,j) = raintot(i,j) + dt*rrate
   46    continue
   45 continue
c
c     Find maximum storm total rainfall
      xmax=0.0
      ymax=0.0
      rainmax=0.0
      do 48 j=1,ny
      do 48 i=1,nx
	 if (raintot(i,j) .gt. rainmax) then
	    rainmax = raintot(i,j)
	    xmax    = glon(i)
	    ymax    = glat(j)
         endif
   48 continue
c
      write(lulog,250) rainmax,xmax,ymax
  250 format(/,1x,'Max rain=',f4.1,' at lon/lat: ',f8.3,1x,f8.3)
c
      return
      end
C------------------------------------------------------------------------------
      subroutine rrcal(time,vmax,rad,rrate)
c     This routine calculates the rain rate (rrate, inches per hour)
c     as a function of the time inland (time, hr), the maximum 
c     winds (vmax, kt), and the radius from the storm center (rad, km).
c
c     Set igauge=1 to use rate from rain gauge analysis
c      or igauge=0 to use rate from TRMM climatology
c
      igauge= 0
c
      if (igauge .eq. 0) go to 1000
c
c     Rainfall rate from gauge climatology (function of t,r)
      a0  = 6.4/24.0
      b0  = 1.0/24.0
      al  = 0.029
      srad = 20.0
      erad = 160.0
c
      tt = time
      if (tt .lt. 0.0) tt = 0.0 
      tf = exp(-al*tt)
c
      if (rad .le. srad) then
	 rrate = (a0*tf+b0)
      else
         rrate = (a0*tf+b0)*exp(-(rad-srad)/erad)
      endif
c
      return
c
 1000 continue
c     Rainfall rate from TRMM climatology (function of vmax,r)
c
      vmaxt = vmax
      if (vmaxt .lt.  35.0) vmaxt = 35.0
      if (vmaxt .gt. 136.0) vmaxt = 136.0
c
      xn = 1.0 + (vmaxt - 35.0)/33.0
c
      t0 =  (3.96*xn - 1.10)/24.0
      tm =  (4.80*xn - 1.60)/24.0
      rm =  -13.0*xn + 64.5
      re = -16.0*xn + 150.0
c
      if (rad .le. rm) then
	 rrate = t0 + (tm-t0)*(rad/rm)
      else
	 rrate = tm*exp(-(rad-rm)/re)
      endif
c
      return
      end
C-------------------------------------------------------------------------------
      subroutine distk(rlon1,rlat1,rlon2,rlat2,dx,dy,rad)
c     This routine calculates the distance in km (rad) between the
c     points (rlon1,rlat1) and (rlon2,rlat2) using an approximate
c     formula. The lon and lat are in deg E and N. The east and
c     north components of the distance (dx,dy) are also calculated.
c
      dtk = 111.12  ! fdm
      dtr = 0.0174533
c
      cfac = cos(0.5*dtr*(rlat1+rlat2))
c
      dx  = dtk*(rlon2-rlon1)*cfac
      dy  = dtk*(rlat2-rlat1)
      rad = sqrt(dx*dx + dy*dy)
c
      return
      end
C-------------------------------------------------------------------------------
      subroutine spdhead(x1,y1,t1,x2,y2,t2,spd,head)
c     This routine calculates the speed (kt) and heading 
c     (deg clockwise from north) given the lon,lat (x1,y1)
c     at time t1 and lon,lat (x2,y2) at time t2. 
c     x1,x2 are deg E  (deg W negative)
c     y1,y2 are deg N  
c     t1,t2 are in hours, with t2 > t1
c
      if (t1 .ge. t2) then
	 spd = 0.0
	 head = 0.0
	 return
      endif
c
      call distk(x1,y1,x2,y2,dx,dy,rad)
c     
      dt   = t2-t1
      radn = rad*60.0/111.12
      spd  = radn/dt
c
      call ctorh(dx,dy,r,head)
c
      return
      end